@@ -1680,9 +1680,9 @@ static int scan_string(context_t* ctx, char* p, int lineno, int dotisspecial)
 	}
 
 	if ('\"' == *p) {
-		char* tsq = strstr(p, "\'\'\'");
 		int hexreq = 0;		/* #hex required */
 		int escape = 0;
+		int sqcnt = 0;		/* count single-quote */
 		for (p++; *p; p++) {
 			if (escape) {
 				escape = 0;
@@ -1696,18 +1696,23 @@ static int scan_string(context_t* ctx, char* p, int lineno, int dotisspecial)
 				if (strchr("0123456789ABCDEF", *p)) continue;
 				return e_syntax(ctx, lineno, "expect hex char");
 			}
+			if (sqcnt) {
+				if (*p == '\'') {
+					if (++sqcnt < 3) continue;
+					return e_syntax(ctx, lineno, "triple-s-quote inside string lit");
+				}
+				sqcnt = 0;
+			}
+
 			if (*p == '\\') { escape = 1; continue; }
+			if (*p == '\'') { sqcnt = 1; continue; }
 			if (*p == '\n') break;
-			if (*p == '"') break;
+			if (*p == '"')  break;
 		}
 		if (*p != '"') {
 			return e_syntax(ctx, lineno, "unterminated quote");
 		}
 
-		if (tsq && tsq < p) {
-			return e_syntax(ctx, lineno, "triple-s-quote inside string lit");
-		}
-
 		set_token(ctx, STRING, lineno, orig, p + 1 - orig);
 		return 0;
 	}
